@@ -70,9 +70,10 @@ def register_fedora(context):
 
 def register_rhel(context):
     context.add_os_installer_key(OS_RHEL, PIP_INSTALLER)
+    context.add_os_installer_key(OS_RHEL, DNF_INSTALLER)
     context.add_os_installer_key(OS_RHEL, YUM_INSTALLER)
     context.add_os_installer_key(OS_RHEL, SOURCE_INSTALLER)
-    context.set_default_os_installer_key(OS_RHEL, lambda self: YUM_INSTALLER)
+    context.set_default_os_installer_key(OS_RHEL, lambda self: DNF_INSTALLER if self.get_version().split('.', 1)[0].isdigit() and int(self.get_version().split('.', 1)[0]) >= 8 else YUM_INSTALLER)
     context.set_os_version_type(OS_RHEL, lambda self: self.get_version().split('.', 1)[0])
 
 
@@ -154,6 +155,24 @@ def rpm_expand(package, exec_fn=None):
         return rpm_expand_cmd(package, exec_fn)
 
 
+def get_rpm_version_py():
+    from rpm import __version__ as rpm_version
+    return rpm_version
+
+
+def get_rpm_version_cmd():
+    output = subprocess.check_output(['rpm', '--version'])
+    version = output.splitlines()[0].split(b' ')[-1].decode()
+    return version
+
+
+def get_rpm_version():
+    try:
+        return get_rpm_version_py()
+    except ImportError:
+        return get_rpm_version_cmd()
+
+
 class DnfInstaller(PackageManagerInstaller):
     """
     This class provides the functions for installing using dnf
@@ -164,6 +183,15 @@ class DnfInstaller(PackageManagerInstaller):
     def __init__(self):
         super(DnfInstaller, self).__init__(rpm_detect)
 
+    def get_version_strings(self):
+        dnf_output = subprocess.check_output(['dnf', '--version'])
+        dnf_version = dnf_output.splitlines()[0].decode()
+        version_strings = [
+            'dnf {}'.format(dnf_version),
+            'rpm {}'.format(get_rpm_version()),
+        ]
+        return version_strings
+
     def get_install_command(self, resolved, interactive=True, reinstall=False, quiet=False):
         raw_packages = self.get_packages_to_install(resolved, reinstall=reinstall)
         packages = [rpm_expand(package) for package in raw_packages]
@@ -190,6 +218,15 @@ class YumInstaller(PackageManagerInstaller):
     def __init__(self):
         super(YumInstaller, self).__init__(rpm_detect)
 
+    def get_version_strings(self):
+        yum_output = subprocess.check_output(['yum', '--version'])
+        yum_version = yum_output.splitlines()[0].decode()
+        version_strings = [
+            'yum {}'.format(yum_version),
+            'rpm {}'.format(get_rpm_version()),
+        ]
+        return version_strings
+
     def get_install_command(self, resolved, interactive=True, reinstall=False, quiet=False):
         raw_packages = self.get_packages_to_install(resolved, reinstall=reinstall)
         packages = [rpm_expand(package) for package in raw_packages]
