@@ -58,14 +58,14 @@ def create_test_SourcesListLoader():
 def get_cache_raw():
     cache_rosdep_path = os.path.join(get_cache_dir(), '0a12d6e7b0d47be9b76e7726720e4cb79528cbaa')
     with open(cache_rosdep_path) as f:
-        cache_raw = yaml.load(f.read())
+        cache_raw = yaml.safe_load(f.read())
     return cache_raw
 
 
 def get_cache_raw_python():
     cache_rosdep_path = os.path.join(get_cache_dir(), 'f6f4ef95664e373cd4754501337fa217f5b55d91')
     with open(cache_rosdep_path) as f:
-        cache_raw = yaml.load(f.read())
+        cache_raw = yaml.safe_load(f.read())
     return cache_raw
 
 
@@ -125,7 +125,7 @@ def test_RosdepDefinition():
         pass
 
     #  - test w/valid data
-    d2 = yaml.load(FAKE_TINYXML_RULE)['testtinyxml']
+    d2 = yaml.safe_load(FAKE_TINYXML_RULE)['testtinyxml']
     definition = RosdepDefinition('d2', d2, 'file2.txt')
     #  - tripwire
     str(definition)
@@ -182,6 +182,26 @@ def test_RosdepDefinition():
     val = definition.get_rule_for_platform('ubuntu', 'trusty', ['apt', 'source', 'pip'], 'apt')
     assert val == ('apt', ['libtinyxml2-dev']), val
 
+    definition = RosdepDefinition('trusty_only_key', {'ubuntu': {'*': None, 'trusty': ['trusty_only_pkg']}, 'debian': None}, 'wildcard.txt')
+    try:
+        val = definition.get_rule_for_platform('ubuntu', 'lucid', ['apt', 'source', 'pip'], 'apt')
+        assert False, 'should have raised: %s' % (str(val))
+    except ResolutionError as e:
+        assert e.rosdep_key == 'trusty_only_key'
+        assert e.os_name == 'ubuntu'
+        assert e.os_version == '*'
+        # tripwire
+        str(e)
+    try:
+        val = definition.get_rule_for_platform('debian', 'stretch', ['apt', 'source', 'pip'], 'apt')
+        assert False, 'should have raised: %s' % (str(val))
+    except ResolutionError as e:
+        assert e.rosdep_key == 'trusty_only_key'
+        assert e.os_name == 'debian'
+        assert e.os_version == 'stretch'
+        # tripwire
+        str(e)
+
     # test reverse merging OS things (first is default)
     definition = RosdepDefinition('test', {'debian': 'libtest-dev'}, 'fake-1.txt')
     # rule should work as expected before reverse-merge
